@@ -3,21 +3,21 @@ import re
 import gtk
 import gtk.glade
 import gobject
+import gnome
+import gnome.ui
 try:
-        import nautilusburn
+        import braseromedia
 except ImportError:
         pass
-else:
-        pass
 
 import backupsets
 import dialogs
 from filechooser import FileChooser
 
 class SetEditor:
-    def __init__(self, backupsets):
+    def __init__(self, bupsets):
         self.exitnotify = None
-        self.backupsets = backupsets
+        self.backupsets = bupsets
         try:
             self.widgets = gtk.glade.XML("%s/seteditor.glade"
                            % os.path.dirname(__file__))
@@ -48,6 +48,7 @@ class SetEditor:
         self.widgets.get_widget('cmb_dst_type').set_active(0)
         self.widgets.get_widget('notebook').set_current_page(0)
 
+        self.drive_sel = None
         self.find_cd_burners()
 
     def _new_column(self):
@@ -121,6 +122,7 @@ class SetEditor:
                 False otherwise
         """
 
+        druidfilelist = self.widgets.get_widget('treeview_druidfilelist')
         if buset is not None:
             if buset.name == _('home'):
                 return False
@@ -145,20 +147,11 @@ class SetEditor:
                 self.widgets.get_widget('entry_ssh_host').set_text(host)
                 self.widgets.get_widget('entry_ssh_path').set_text(path)
             elif buset.dest[:7] == "cdrw://":
-                device = buset.dest.replace("cdrw://", "")
                 self.widgets.get_widget('cmb_dst_type').set_active(1)
-                found = False
-                for row in self.widgets.get_widget('cmb_dst_burner').get_model():
-                    if row[1].get_device() == device:
-                        self.widgets.get_widget('cmb_dst_burner').set_active_iter(row.iter)
-                        found = True
-                if not found:
-                    self.widgets.get_widget('cmb_dst_burner').set_active(0)
             else:
                 self.widgets.get_widget('cmb_dst_type').set_active(0)
                 self.widgets.get_widget('entry_new_set_def_dest').set_text(buset.dest)
             self.widgets.get_widget('new_set_overwrite').set_active(True)
-            druidfilelist = self.widgets.get_widget('treeview_druidfilelist')
             druidfilelistmodel = druidfilelist.get_model()
             for f in buset.files_exclude:
                 if f == "**":
@@ -180,14 +173,21 @@ class SetEditor:
                     druidfilelistmodel.append([druidfilelist.render_icon(gtk.STOCK_ADD,\
                         gtk.ICON_SIZE_MENU, "TreeView"), druidfilelist.render_icon(\
                         gtk.STOCK_FILE, gtk.ICON_SIZE_MENU, "TreeView"), f, True])
+            self.widgets.get_widget('window_new_set').set_title(_("Editing backup set '%s'") % buset.name)
+            self.widgets.get_widget('druid1').set_page(self.widgets.get_widget('druid_page_2'))
+        else:
+            self.widgets.get_widget('entry_new_set_name').set_text("")
+            self.widgets.get_widget('entry_new_set_desc').set_text("")
+            self.widgets.get_widget('entry_new_set_name').set_sensitive(True)
+            self.widgets.get_widget('window_new_set').set_title(_("Editing new backup set"))
+            self.widgets.get_widget('druid1').set_page(self.widgets.get_widget('druid_page_start'))
+
         if len(druidfilelist)==1:
             self.widgets.get_widget('druidfilelist_label').set_text("1 item")
         else:
             self.widgets.get_widget('druidfilelist_label').set_text("%d items"%len(druidfilelist))
         self.widgets.get_widget('druid_page_start').show()
         self.widgets.get_widget('druid_page_finish').show()
-        self.widgets.get_widget('druid1').set_page(self.widgets.get_widget('druid_page_2'))
-        self.widgets.get_widget('window_new_set').set_title(_("Editing backup set '%s'") % buset.name)
         return True
 
     # Event handlers start here
@@ -240,12 +240,14 @@ class SetEditor:
             self.widgets.get_widget('druid_summary_dest').set_text("sftp://%s@%s%s" % (user, host, path))
 
         elif self.widgets.get_widget('cmb_dst_type').get_active() == 1: # CD burner
-            if self.widgets.get_widget('cmb_dst_burner').get_active() == -1:
+            if self.drive_sel is None:
                 return True
-            dest = self.widgets.get_widget('cmb_dst_burner').get_model()[self.widgets.get_widget('cmb_dst_burner').get_active()][1].get_device()
-            self.widgets.get_widget('druid_summary_dest').set_text("cdrw://%s" % dest)
-            self.widgets.get_widget('chk_removable_device').set_active(True)
-        self.widgets.get_widget('druid_page_3').set_title("Add Files/Folders to '%s'" % self.widgets.get_widget('entry_new_set_name').get_text())
+            active = self.drive_sel.get_active()
+            if active:
+		    dest = active.get_block_device()
+		    self.widgets.get_widget('druid_summary_dest').set_text("cdrw://%s" % dest)
+		    self.widgets.get_widget('chk_removable_device').set_active(True)
+        self.widgets.get_widget('druid_page_3').set_title(_("Add Files/Folders to '%s'") % self.widgets.get_widget('entry_new_set_name').get_text())
         self.widgets.get_widget('druid_summary_name').set_text(self.widgets.get_widget('entry_new_set_name').get_text())
         self.widgets.get_widget('druid_summary_desc').set_text(self.widgets.get_widget('entry_new_set_desc').get_text())
     
@@ -278,15 +280,12 @@ class SetEditor:
         filechooser = FileChooser()
         filechooser.set_return_type(filechooser.RETURN_FILENAME)
         filechooser.set_exitnotify(self.filechosen_new_set_default_dest)
-        filechooser.set_title(_("Select a default location to backup to"))
+        filechooser.set_title(_("Select a default destination"))
         filechooser.show()
     
     def filechosen_new_set_default_dest(self, filename):
         self.widgets.get_widget('entry_new_set_def_dest').set_text(filename)
 
-    def on_button_refresh_cd_burners_clicked(self, widget):
-        self.find_cd_burners()
-
     def on_druid_page_finish_prepare(self, widget, event):
         event.set_buttons_sensitive(False, False, False, False)
                 
@@ -365,23 +364,16 @@ class SetEditor:
 
         """ Populate a combo box with the names of available CD/DVD drives """
         try:
-            nautilusburn
+            braseromedia
         except NameError:
             error_string = _("No CD burners available, because you do not have the python module \
-nautilusburn.")
+braseromedia.")
             self.widgets.get_widget('lbl_cd_burner').set_text(error_string)
-            self.widgets.get_widget('cmb_dst_burner').set_sensitive(False)
         else:
-            sel = nautilusburn.DriveSelection()
-            self.widgets.get_widget('cmb_dst_burner').set_model(sel.get_model())
-
-            if len(sel.get_model()) == 0:
-                error_string = _("No CD burners were detected on your system.")
-                self.widgets.get_widget('lbl_cd_burner').set_text(error_string)
-                self.widgets.get_widget('cmb_dst_burner').set_sensitive(False)
-            else:
-                msg_string = _("Select which CD burner to use:")
-                self.widgets.get_widget('lbl_cd_burner').set_text(msg_string)
-                self.widgets.get_widget('cmb_dst_burner').set_active(0)
-                self.widgets.get_widget('cmb_dst_burner').set_sensitive(True)
+            self.drive_sel = braseromedia.DriveSelection()
+            self.widgets.get_widget('hbox30').add(self.drive_sel)
+            self.drive_sel.show()
 
+    def on_hiddenfiles_toggled(self, event):
+        fc = self.widgets.get_widget('filechooserwidget1')
+        fc.set_show_hidden(event.get_active())
